log using coefgraph2.log, replace

/************************************************/
/* 2nd LFP Regression Coeff Graph w/ March CPS 	*/
/* Coile, Duggan, Guo							*/
/* January 09, 2015  							*/
/************************************************/
clear all
set more off

use cpsmaster.dta, clear

// Divide into Year Groups
gen group=1 if year>=1980 & year<=1984
replace group=2 if year>=1985 & year<=1989 
replace group=3 if year>=1990 & year<=1994
replace group=4 if year>=1995 & year<=1999
replace group=5 if year>=2000 & year<=2004
replace group=6 if year>=2005 & year<=2009
replace group=7 if year>=2010 & year<=2014

// Age 25-34 //
matrix vet25_34 = J(7,3,.)
matrix coln vet25_34 = coeff l95 u95
matrix rown vet25_34 = 80-84 85-89 90-94 95-99 00-04 05-09 10-14

forval i=1/7 {
	areg inlf vet black other hispanic yearDV* if a_age>=25 & a_age<=34 & group==`i' [aw=a_fnlwgt], a(a_age) 
	matrix vet25_34[`i',1] = _b[vet], _b[vet]-1.96*_se[vet], _b[vet]+1.96*_se[vet]
	}
	
matrix list vet25_34

// Age 35-54 //
matrix vet35_54 = J(7,3,.)
matrix coln vet35_54 = coeff l95 u95
matrix rown vet35_54 = 80-84 85-89 90-94 95-99 00-04 05-09 10-14

forval i=1/7 {
	areg inlf vet black other hispanic yearDV* if a_age>=35 & a_age<=54 & group==`i' [aw=a_fnlwgt], a(a_age) 
	matrix vet35_54[`i',1] = _b[vet], _b[vet]-1.96*_se[vet], _b[vet]+1.96*_se[vet]
	}
	
matrix list vet35_54

// Age 55-64 //
matrix vet55_64 = J(7,3,.)
matrix coln vet55_64 = coeff l95 u95
matrix rown vet55_64 = 80-84 85-89 90-94 95-99 00-04 05-09 10-14

forval i=1/7 {
	areg inlf vet black other hispanic yearDV* if a_age>=55 & a_age<=64 & group==`i' [aw=a_fnlwgt], a(a_age) 
	matrix vet55_64[`i',1] = _b[vet], _b[vet]-1.96*_se[vet], _b[vet]+1.96*_se[vet]
	}
	
matrix list vet55_64

// Age 65-74 //
matrix vet65_74 = J(7,3,.)
matrix coln vet65_74 = coeff l95 u95
matrix rown vet65_74 = 80-84 85-89 90-94 95-99 00-04 05-09 10-14

forval i=1/7 {
	areg inlf vet black other hispanic yearDV* if a_age>=65 & a_age<=74 & group==`i' [aw=a_fnlwgt], a(a_age) 
	matrix vet65_74[`i',1] = _b[vet], _b[vet]-1.96*_se[vet], _b[vet]+1.96*_se[vet]
	}
	
matrix list vet65_74

coefplot (matrix(vet25_34[,1]), ci((vet25_34[,2] vet25_34[,3]))) || (matrix(vet35_54[,1]), ci((vet35_54[,2] vet35_54[,3]))) || ///
(matrix(vet55_64[,1]), ci((vet55_64[,2] vet55_64[,3]))) || (matrix(vet65_74[,1]), ci((vet65_74[,2] vet65_74[,3]))), yline(0) vertical ///
xtitle("Year groups") ytitle("Coefficients on Veteran") scheme(s1mono)

graph export Graph2.png, replace

log close
